@@ -2,15 +2,9 @@ mod add;
 mod index;
 mod mul;
 
-use crate::{
-    nodes::{Literal, Value},
-    NoteError, Result,
-};
+use crate::{nodes::Value, NoteError, Result};
 use num::{BigInt, Signed, ToPrimitive};
-use std::{
-    collections::BTreeSet,
-    ops::{Add, Div, Mul, Neg, Shr, Sub},
-};
+use std::ops::{Add, Div, Mul, Neg, Shr, Sub};
 
 fn fail_int2dec(n: BigInt) -> Result<Value> {
     Err(NoteError::runtime_error(format!("Can not convert `Integer` {} to `Decimal`", n)))
